@@ -1,4 +1,4 @@
-# Copyright (c) 2009 Denis Bilenko. See LICENSE for details.
+# Copyright (c) 2009-2010 Denis Bilenko. See LICENSE for details.
 
 import sys
 import traceback
@@ -80,7 +80,10 @@ class GreenletLink(object):
 
     def __call__(self, source):
         if source.successful():
-            error = getLinkedCompleted(source)
+            if isinstance(source.value, GreenletExit):
+                error = LinkedKilled(source)
+            else:
+                error = LinkedCompleted(source)
         else:
             error = LinkedFailed(source)
         current = getcurrent()
@@ -181,7 +184,7 @@ class Greenlet(greenlet):
         else:
             args = []
             if self.args:
-                args = [repr(x) for x in self.args]
+                args = [repr(x)[:50] for x in self.args]
             if self.kwargs:
                 args.extend(['%s=%r' % x for x in self.kwargs.items()])
             if args:
@@ -199,8 +202,8 @@ class Greenlet(greenlet):
     def throw(self, *args):
         """Immediatelly switch into the greenlet and raise an exception in it.
 
-        Can only be called from the HUB, otherwise the current greenlet is left unscheduled forever.
-        To raise an exception in a safely manner, use :meth:`kill`.
+        Should only be called from the HUB, otherwise the current greenlet is left unscheduled forever.
+        To raise an exception in a safely manner from any greenlet, use :meth:`kill`.
         """
         if self._start_event is not None:
             self._start_event.cancel()
@@ -217,7 +220,15 @@ class Greenlet(greenlet):
                 else:
                     self._exception = args[1]
                 try:
-                    return greenlet.throw(self, *args)
+                    try:
+                        # Even though the greenlet is not yet started, we calling throw() here
+                        # so that its 'dead' attribute becomes True
+                        return greenlet.throw(self, *args)
+                    except:
+                        # since this function is called from the Hub, which is the parent of *greenlet*
+                        # the above statement will re-reraise here whatever we've thrown in it
+                        # this traceback is useless, so we silent it
+                        pass
                 finally:
                     if self._links and self._notifier is None:
                         self._notifier = core.active_event(self._notify_links)
@@ -253,20 +264,20 @@ class Greenlet(greenlet):
         return g
 
     @classmethod
-    def spawn_link(cls, function, *args, **kwargs):
-        g = cls.spawn(function, *args, **kwargs)
+    def spawn_link(cls, *args, **kwargs):
+        g = cls.spawn(*args, **kwargs)
         g.link()
         return g
 
     @classmethod
-    def spawn_link_value(cls, function, *args, **kwargs):
-        g = cls.spawn(function, *args, **kwargs)
+    def spawn_link_value(cls, *args, **kwargs):
+        g = cls.spawn(*args, **kwargs)
         g.link_value()
         return g
 
     @classmethod
-    def spawn_link_exception(cls, function, *args, **kwargs):
-        g = cls.spawn(function, *args, **kwargs)
+    def spawn_link_exception(cls, *args, **kwargs):
+        g = cls.spawn(*args, **kwargs)
         g.link_exception()
         return g
 
@@ -324,7 +335,7 @@ class Greenlet(greenlet):
             raise Timeout
 
     def join(self, timeout=None):
-        """Wait until the greenlet dies or *timeout* expires.
+        """Wait until the greenlet finishes or *timeout* expires.
         Return ``None`` regardless.
         """
         if self.ready():
@@ -400,7 +411,7 @@ class Greenlet(greenlet):
     def link(self, receiver=None, GreenletLink=GreenletLink, SpawnedLink=SpawnedLink):
         """Link greenlet's completion to callable or another greenlet.
 
-        If *receiver* is a callable then it will be called and passed this instance
+        If *receiver* is a callable then it will be called with this instance as an argument
         once this greenlet's dead. A callable is called in its own greenlet.
 
         If *receiver* is a greenlet then an :class:`LinkedExited` exception will be
@@ -416,7 +427,7 @@ class Greenlet(greenlet):
         if receiver is None or receiver is current:
             receiver = GreenletLink(current)
             if self.ready():
-                # special case : linking to current greenlet when link is ready
+                # special case : linking to current greenlet when the result is ready
                 # raise LinkedExited immediatelly
                 receiver(self)
                 return
@@ -454,7 +465,7 @@ class Greenlet(greenlet):
                     try:
                         sys.stderr.write('Failed to notify link %s of %r\n\n' % (getfuncname(link), self))
                     except:
-                        pass
+                        traceback.print_exc()
         finally:
             self._notifier = None
 
@@ -552,13 +563,6 @@ class LinkedKilled(LinkedCompleted):
         LinkedExited.__init__(self, self.msg % (source, result))
 
 
-def getLinkedCompleted(source):
-    if isinstance(source.value, GreenletExit):
-        return LinkedKilled(source)
-    else:
-        return LinkedCompleted(source)
-
-
 class LinkedFailed(LinkedExited):
     """Raised when a linked greenlet dies because of unhandled exception"""
 
